==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Zeitüberschreitung bei der Authentifizierung</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Die Festplatte wird verwndet und kann jetzt nicht ausgehängt werden</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Festplatte wird verwendet, sie kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Das Gerät ist beschäftigt, kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Das Gerät ist beschäftigt, kann jetzt nicht entfernt werden</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Laufwerk</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Das Gerät wurde nicht sicher entfernt</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klicke auf „Sicher entfernen“ und trenne die Verbindung dann beim nächsten Mal</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Das Gerät ist beschäftigt, kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Das Gerät ist beschäftigt, kann jetzt nicht entfernt werden</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Kann das Gerät nicht aushängen</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Das Laufwerk ist bereits vom Benutzer &quot;%1&quot; eingehängt, Sie können es nicht aushängen.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Kann das eingehängte Gerät nicht finden</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Festplatten</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Laufwerk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Alle auswerfen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Das Gerät wurde sicher entfernt</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Zugriff verweigert</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Sie haben keine Berechtigung, um auf diesen Ordner zuzugreifen</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Zeitüberschreitung bei der Authentifizierung</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Laufwerk wird verwendet, es kann jetzt nicht ausgehängt werden</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Datenträger wird verwendet, er kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Das Gerät ist beschäftigt, kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Das Gerät ist beschäftigt, kann jetzt nicht entfernt werden</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Laufwerk</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Das Gerät wurde nicht sicher entfernt</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Klicke auf „Sicher entfernen“ und trenne die Verbindung dann beim nächsten Mal</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Kann das Gerät nicht aushängen</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Das Laufwerk ist vom Benutzer „%1“ eingehängt, Sie können es nicht aushängen.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Kann das eingehängte Gerät nicht finden</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Laufwerke</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Laufwerk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Alle auswerfen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Das Gerät wurde sicher entfernt</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Zugriff verweigert</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Sie haben keine Berechtigung, um auf diesen Ordner zuzugreifen</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Stopp</translation>
    </message>
</context>
</TS>
